#!perl
BEGIN
{
    use lib './lib';
    use Test::More;
	unless( $ENV{AUTHOR_TESTING} || $ENV{RELEASE_TESTING} )
	{
		plan(skip_all => 'These tests are for author or release candidate testing');
	}
};

eval "use Test::Pod 1.00";
plan( skip_all => "Test::Pod 1.00 required for testing POD" ) if( $@ );
all_pod_files_ok();

__END__

